"""
This is the nester module.  It provides one function called print_lol()
which prints lists that may or may not include nested lists."""

def print_lol(the_list,level):
    """ This function takes a positional aruguemt called "the_list", which is any Python list, and may contain nested lists, and recursively printes each 
    item to the screen on its own line.
    """
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, level+1)
        else:
            for tab_stop in range(level):
                print("\t", end='')
            print(each_item)



from distutils.core import setup

setup(
	name			=	'nester_rc54',
	version 		=	'1.2.0',
	py_modules		=	['nester_rc54'],
	author			=	'rchilders',
	author_email	=	'rchilders54@gmail.com',
	url				=	'http://richardchilders.ca',
	description		=	'A simple printer of nested lists',
	)